@@ -16,11 +16,11 @@ Time::Random - Generate a random time in time.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -45,10 +45,8 @@ our $VERSION = '0.02';
 
 =head1 EXPORT
 
-=head1 SUBROUTINES/METHODS
-
 =head2 time_random
-
+ 
 =cut
 
 sub time_random {
@@ -59,11 +57,10 @@ sub time_random {
 			: ref $args{$_}
 				? $args{$_}->epoch()
 				: $args{$_}
-		: $_ eq 'to' ? time() : $args{to} - int(rand($args{to} - 86400))
+		: $_ eq 'to' ? time : ($args{to} - int(rand(86400)))
 	foreach qw/to from/;
-	do { $args{time} = gmtime($args{to} - int(rand($args{to} - $args{from}))) } && $args{strftime} 
-		? $args{time}->strftime($args{strftime}) 
-		: $args{time};
+	$args{time} = gmtime($args{to} - int(rand($args{to} - $args{from}))); 
+	$args{strftime} ? $args{time}->strftime($args{strftime}) : $args{time};
 }
 
 =head1 AUTHOR
